@@ -109,7 +109,7 @@ class FitMosaicSources(object):
             self.residuals[~mask] = 0
             ndof = r[mask].flatten().shape[0]
             residual = (r[mask]**2).sum()/ndof
-            # print("------------->", x, local_model.sum(), residual, ndof, residual/ndof)
+            #print("------------->", x, local_model.sum(), residual, ndof, residual/ndof)
             return residual
 
         x0 = []
@@ -184,7 +184,7 @@ class FitMosaicSources(object):
         variance_i = []
 
         for ie, e in enumerate(f):
-            if 'IMATYPE' in e.header and e.header['IMATYPE'] == "INTENSITY":
+            if 'IMATYPE' in e.header and ( e.header['IMATYPE'] == "INTENSITY" or e.header['IMATYPE'] == "RECONSTRUCTED"):
                     intensity_i.append(ie)
 
             if 'IMATYPE' in e.header and e.header['IMATYPE'] == "VARIANCE":
